@@ -1011,7 +1011,6 @@ static char cursor_bits[] = {
 void
 gok_main_set_cursor (GdkCursor *cursor)
 {
-	GdkPixmap *source;
 	GdkColor color = { 0, 0, 0, 0 };
 	static GdkCursor *nilCursor = NULL;
 	if (!cursor) {
@@ -1228,7 +1227,6 @@ static gboolean gok_main_xevie_io (GIOChannel *source,
 				   GIOCondition condition,
 				   gpointer data)
 {
-    XEvent xevie_event;
 #ifdef HAVE_XEVIE
     while (xevie_dpy && XPending (xevie_dpy)) {
       XMotionEvent *motion_event;
@@ -1828,7 +1826,6 @@ GtkWidget* gok_main_create_window (struct gok_window_realize_data *window_realiz
 {
 	GtkWidget *window1;
 	GtkWidget *fixed1;
-	GtkWidget *event1;
 
 	gok_log_enter();
 					
@@ -2836,7 +2833,6 @@ gok_main_window_contains_pointer (void)
 {
 	gint x=-1, y=-1, w=0, h=0;
 	gint px, py;
-	GdkModifierType mask;
 	GtkWidget *widget = gok_main_get_main_window ();
 	gok_scanner_get_pointer_location (&px, &py);
 	if (widget->window) {
@@ -3155,8 +3151,6 @@ gok_main_warn (gchar *message, gboolean always, GCallback cancelfunc, GCallback
 	if (always || gok_scanner_current_state_uses_corepointer ()) 
 	{
 		GtkWidget*	button;
-		gint         response_id;
-		gboolean 	returnCode = TRUE;
 
 		if (opt_out && okfunc) (*okfunc) ();
 
@@ -3219,8 +3213,6 @@ gok_main_check_accessibility ()
         
     if (!accessibility_on) {
 		GtkWidget*	button;
-		gint         response_id;
-		gboolean 	returnCode = TRUE;
 		
 		acd = gtk_message_dialog_new (
 			NULL, 
